@@ -5,7 +5,6 @@ from __future__ import annotations
 import argparse
 import asyncio
 import contextlib
-import json
 import logging
 import os
 import pathlib
@@ -23,11 +22,18 @@ from time import perf_counter
 from libvcs._internal.shortcuts import create_project
 from libvcs._internal.types import VCSLiteral
 from libvcs.sync.git import GitSync
+from libvcs.sync.hg import HgSync
+from libvcs.sync.svn import SvnSync
 from libvcs.url import registry as url_tools
 
 from vcspull import exc
 from vcspull._internal.private_path import PrivatePath
-from vcspull.config import filter_repos, find_config_files, load_configs
+from vcspull._internal.worktree_sync import (
+    WorktreeAction,
+    plan_worktree_sync,
+    sync_all_worktrees,
+)
+from vcspull.config import expand_dir, filter_repos, find_config_files, load_configs
 from vcspull.types import ConfigDict
 
 from ._colors import Colors, get_color_mode
@@ -196,7 +202,7 @@ def _determine_plan_action(
         return PlanAction.CLONE, "missing"
 
     if not status.get("is_git"):
-        return PlanAction.BLOCKED, "not a git repository"
+        return PlanAction.UPDATE, "non-git VCS (detailed plan not available)"
 
     clean_state = status.get("clean")
     if clean_state is False:
@@ -491,14 +497,9 @@ def _emit_plan_output(
         show_unchanged=render_options.show_unchanged,
     )
 
-    if formatter.mode == OutputMode.NDJSON:
-        for entry in display_entries:
-            formatter.emit(entry)
-        formatter.emit(plan.summary)
-        return
-    structured = PlanResult(entries=display_entries, summary=plan.summary)
-    sys.stdout.write(json.dumps(structured.to_json_object(), indent=2) + "\n")
-    sys.stdout.flush()
+    for entry in display_entries:
+        formatter.emit(entry)
+    formatter.emit(plan.summary)
 
 
 def create_sync_subparser(parser: argparse.ArgumentParser) -> argparse.ArgumentParser:
@@ -596,6 +597,19 @@ def create_sync_subparser(parser: argparse.ArgumentParser) -> argparse.ArgumentP
         default=0,
         help="increase plan verbosity (-vv for maximum detail)",
     )
+    parser.add_argument(
+        "--all",
+        "-a",
+        action="store_true",
+        dest="sync_all",
+        help="sync all configured repositories",
+    )
+    parser.add_argument(
+        "--include-worktrees",
+        action="store_true",
+        dest="include_worktrees",
+        help="also sync configured worktrees for each repository",
+    )
 
     try:
         import shtab
@@ -622,10 +636,22 @@ def sync(
     fetch: bool,
     offline: bool,
     verbosity: int,
+    sync_all: bool = False,
     parser: argparse.ArgumentParser
     | None = None,  # optional so sync can be unit tested
+    include_worktrees: bool = False,
 ) -> None:
     """Entry point for ``vcspull sync``."""
+    # Show help if no patterns and --all not specified
+    if not repo_patterns and not sync_all:
+        if parser is not None:
+            parser.print_help()
+        else:
+            log.warning(
+                "sync() called with no repo patterns and no --all flag; nothing to do",
+            )
+        return
+
     output_mode = get_output_mode(output_json, output_ndjson)
     formatter = OutputFormatter(output_mode)
     colors = Colors(get_color_mode(color))
@@ -647,26 +673,46 @@ def sync(
     found_repos: list[ConfigDict] = []
     unmatched_count = 0
 
-    for repo_pattern in repo_patterns:
-        path, vcs_url, name = None, None, None
-        if any(repo_pattern.startswith(n) for n in ["./", "/", "~", "$HOME"]):
-            path = repo_pattern
-        elif any(repo_pattern.startswith(n) for n in ["http", "git", "svn", "hg"]):
-            vcs_url = repo_pattern
-        else:
-            name = repo_pattern
+    if sync_all:
+        if repo_patterns:
+            msg = "--all cannot be combined with positional patterns"
+            if parser is not None:
+                parser.error(msg)
+            else:
+                raise SystemExit(msg)
+        # Load all repos when --all is specified
+        found_repos = list(configs)
+    else:
+        for repo_pattern in repo_patterns:
+            path, vcs_url, name = None, None, None
+            if any(repo_pattern.startswith(n) for n in ["./", "/", "~", "$HOME"]):
+                path = repo_pattern
+            elif any(repo_pattern.startswith(n) for n in ["http", "git", "svn", "hg"]):
+                vcs_url = repo_pattern
+            else:
+                name = repo_pattern
 
-        found = filter_repos(configs, path=path, vcs_url=vcs_url, name=name)
-        if not found:
-            search_term = name or path or vcs_url or repo_pattern
-            log.debug(NO_REPOS_FOR_TERM_MSG.format(name=search_term))
-            if not summary_only:
-                formatter.emit_text(
-                    f"{colors.error('✗')} "
-                    f"{NO_REPOS_FOR_TERM_MSG.format(name=search_term)}",
-                )
-            unmatched_count += 1
-        found_repos.extend(found)
+            found = filter_repos(configs, path=path, vcs_url=vcs_url, name=name)
+            if not found:
+                search_term = name or path or vcs_url or repo_pattern
+                log.debug(NO_REPOS_FOR_TERM_MSG.format(name=search_term))
+                if not summary_only:
+                    formatter.emit_text(
+                        f"{colors.error('✗')} "
+                        f"{NO_REPOS_FOR_TERM_MSG.format(name=search_term)}",
+                    )
+                unmatched_count += 1
+            found_repos.extend(found)
+
+        # Deduplicate repos matched by multiple patterns
+        seen_paths: set[str] = set()
+        deduped: list[ConfigDict] = []
+        for repo in found_repos:
+            key = str(repo.get("path", ""))
+            if key not in seen_paths:
+                seen_paths.add(key)
+                deduped.append(repo)
+        found_repos = deduped
 
     if workspace_root:
         found_repos = filter_by_workspace(found_repos, workspace_root)
@@ -695,6 +741,44 @@ def sync(
             dry_run=True,
             total_repos=total_repos,
         )
+
+        # Show worktree plans if --include-worktrees is set
+        if include_worktrees:
+            for repo in found_repos:
+                worktrees_config = repo.get("worktrees")
+                if not worktrees_config:
+                    continue
+
+                repo_name = str(repo.get("name", "unknown"))
+                repo_path = _get_repo_path(repo)
+                workspace_label = str(repo.get("workspace_root", ""))
+                workspace_path = expand_dir(pathlib.Path(workspace_label))
+
+                wt_entries = plan_worktree_sync(
+                    repo_path, worktrees_config, workspace_path
+                )
+
+                for entry in wt_entries:
+                    ref_display = f"{entry.ref_type}:{entry.ref_value}"
+                    wt_path_display = str(PrivatePath(entry.worktree_path))
+
+                    action_symbols = {
+                        WorktreeAction.CREATE: colors.success("+"),
+                        WorktreeAction.UPDATE: colors.warning("~"),
+                        WorktreeAction.UNCHANGED: colors.muted("✓"),
+                        WorktreeAction.BLOCKED: colors.warning("⚠"),
+                        WorktreeAction.ERROR: colors.error("✗"),
+                    }
+                    sym = action_symbols.get(entry.action, "?")
+                    ref = colors.info(ref_display)
+                    detail = entry.detail or entry.error or ""
+
+                    formatter.emit_text(
+                        f"  {sym} worktree {colors.info(repo_name)} "
+                        f"{ref} {colors.muted('→')} {wt_path_display}"
+                        f"  {colors.muted(detail)}".rstrip(),
+                    )
+
         formatter.finalize()
         return
 
@@ -809,6 +893,69 @@ def sync(
             f"{colors.muted('→')} {display_repo_path}",
         )
 
+        # Sync worktrees if enabled and configured
+        worktrees_config = repo.get("worktrees")
+        if include_worktrees and worktrees_config:
+            workspace_path = expand_dir(pathlib.Path(str(workspace_label)))
+            repo_path_obj = pathlib.Path(str(repo_path))
+
+            wt_result = sync_all_worktrees(
+                repo_path_obj,
+                worktrees_config,
+                workspace_path,
+                dry_run=dry_run,
+            )
+
+            for entry in wt_result.entries:
+                ref_display = f"{entry.ref_type}:{entry.ref_value}"
+                wt_path_display = str(PrivatePath(entry.worktree_path))
+
+                if entry.action == WorktreeAction.CREATE:
+                    sym = colors.success("+")
+                    ref = colors.info(ref_display)
+                    arrow = colors.muted("→")
+                    formatter.emit_text(
+                        f"    {sym} worktree {ref} {arrow} {wt_path_display}",
+                    )
+                elif entry.action == WorktreeAction.UPDATE:
+                    sym = colors.warning("~")
+                    ref = colors.info(ref_display)
+                    arrow = colors.muted("→")
+                    formatter.emit_text(
+                        f"    {sym} worktree {ref} {arrow} {wt_path_display}",
+                    )
+                elif entry.action == WorktreeAction.BLOCKED:
+                    sym = colors.warning("⚠")
+                    ref = colors.info(ref_display)
+                    formatter.emit_text(
+                        f"    {sym} worktree {ref} blocked: {entry.detail}",
+                    )
+                elif entry.action == WorktreeAction.ERROR:
+                    formatter.emit_text(
+                        f"    {colors.error('✗')} worktree {colors.info(ref_display)} "
+                        f"error: {entry.error}",
+                    )
+
+            # Tally worktree results into summary
+            summary["worktree_created"] = (
+                summary.get("worktree_created", 0) + wt_result.created
+            )
+            summary["worktree_updated"] = (
+                summary.get("worktree_updated", 0) + wt_result.updated
+            )
+            summary["worktree_failed"] = (
+                summary.get("worktree_failed", 0) + wt_result.errors
+            )
+            # Count worktree errors as failures for exit code
+            summary["failed"] += wt_result.errors
+
+            if exit_on_error and wt_result.errors > 0:
+                _emit_summary(formatter, colors, summary)
+                formatter.finalize()
+                if parser is not None:
+                    parser.exit(status=1, message=EXIT_ON_ERROR_MSG)
+                raise SystemExit(EXIT_ON_ERROR_MSG)
+
     _emit_summary(formatter, colors, summary)
 
     if exit_on_error and unmatched_count > 0:
@@ -844,6 +991,20 @@ def _emit_summary(
             parts.append(
                 f", {colors.warning(str(unmatched))} unmatched",
             )
+        wt_created = summary.get("worktree_created", 0)
+        wt_updated = summary.get("worktree_updated", 0)
+        wt_failed = summary.get("worktree_failed", 0)
+        if wt_created or wt_updated or wt_failed:
+            wt_parts = []
+            if wt_created:
+                wt_parts.append(f"{colors.success(str(wt_created))} created")
+            if wt_updated:
+                wt_parts.append(f"{colors.warning(str(wt_updated))} updated")
+            if wt_failed:
+                wt_parts.append(f"{colors.error(str(wt_failed))} failed")
+            parts.append(
+                f"; worktrees: {', '.join(wt_parts)}",
+            )
         formatter.emit_text("".join(parts))
 
 
@@ -896,7 +1057,7 @@ def update_repo(
     repo_dict: t.Any,
     progress_callback: ProgressCallback | None = None,
     # repo_dict: Dict[str, Union[str, Dict[str, GitRemote], pathlib.Path]]
-) -> GitSync:
+) -> GitSync | HgSync | SvnSync:
     """Synchronize a single repository."""
     repo_dict = deepcopy(repo_dict)
     if "pip_url" not in repo_dict:
@@ -913,7 +1074,7 @@ def update_repo(
 
         repo_dict["vcs"] = vcs
 
-    r = create_project(**repo_dict)  # Creates the repo object
+    r: GitSync | HgSync | SvnSync = create_project(**repo_dict)
     if repo_dict.get("vcs") == "git":
         result = r.update_repo(set_remotes=True)
     else:
@@ -924,5 +1085,4 @@ def update_repo(
         repo_name = str(repo_dict.get("name", repo_dict.get("url", "unknown")))
         raise SyncFailedError(repo_name=repo_name, errors=error_messages)
 
-    # TODO: Fix this
-    return r  # type:ignore
+    return r
